timeintervaltools.fuse_overlapping_intervals
============================================

.. autofunction:: abjad.tools.timeintervaltools.fuse_overlapping_intervals.fuse_overlapping_intervals
   :noindex:
